@@ -1,4 +1,4 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
+/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
@@ -8,9 +8,22 @@ Components.utils.import("resource:///modules/iteratorUtils.jsm");
 Components.utils.import("resource:///modules/mailServices.js");
 Components.utils.import("resource://gre/modules/Services.jsm");
 
-var gFilterListMsgWindow = null;
-var gCurrentFilterList;
-var gCurrentFolder;
+let gFilterListMsgWindow = null;
+let gCurrentFilterList;
+let gCurrentFolder;
+
+let gFilterListbox = null;
+let gEditButton = null;
+let gDeleteButton = null;
+let gTopButton = null;
+let gUpButton = null;
+let gDownButton = null;
+let gBottomButton = null;
+let gSearchBox = null;
+let gRunFiltersFolder = null;
+let gRunFiltersButton = null;
+
+let gFilterBundle = null;
 
 const msgMoveMotion = {
   Up     : 0,
@@ -19,7 +32,6 @@ const msgMoveMotion = {
   Bottom : 3
 }
 
-
 var gStatusFeedback = {
   progressMeterVisible : false,
 
@@ -30,9 +42,8 @@ var gStatusFeedback = {
   startMeteors: function()
   {
     // change run button to be a stop button
-    var runButton = document.getElementById("runFiltersButton");
-    runButton.setAttribute("label", runButton.getAttribute("stoplabel"));
-    runButton.setAttribute("accesskey", runButton.getAttribute("stopaccesskey"));
+    gRunFiltersButton.setAttribute("label", gRunFiltersButton.getAttribute("stoplabel"));
+    gRunFiltersButton.setAttribute("accesskey", gRunFiltersButton.getAttribute("stopaccesskey"));
 
     if (!this.progressMeterVisible)
     {
@@ -46,9 +57,8 @@ var gStatusFeedback = {
   {
     try {
       // change run button to be a stop button
-      var runButton = document.getElementById("runFiltersButton");
-      runButton.setAttribute("label", runButton.getAttribute("runlabel"));
-      runButton.setAttribute("accesskey", runButton.getAttribute("runaccesskey"));
+      gRunFiltersButton.setAttribute("label", gRunFiltersButton.getAttribute("runlabel"));
+      gRunFiltersButton.setAttribute("accesskey", gRunFiltersButton.getAttribute("runaccesskey"));
 
       if (this.progressMeterVisible)
       {
@@ -88,6 +98,18 @@ function onLoad()
     gFilterListMsgWindow.rootDocShell.appType = Components.interfaces.nsIDocShell.APP_TYPE_MAIL;
     gFilterListMsgWindow.statusFeedback = gStatusFeedback;
 
+    gFilterListbox    = document.getElementById("filterList");
+    gEditButton       = document.getElementById("editButton");
+    gDeleteButton     = document.getElementById("deleteButton");
+    gTopButton        = document.getElementById("reorderTopButton");
+    gUpButton         = document.getElementById("reorderUpButton");
+    gDownButton       = document.getElementById("reorderDownButton");
+    gBottomButton     = document.getElementById("reorderBottomButton");
+    gSearchBox        = document.getElementById("searchBox");
+    gRunFiltersFolder = document.getElementById("runFiltersFolder");
+    gRunFiltersButton = document.getElementById("runFiltersButton");
+    gFilterBundle     = document.getElementById("bundle_filter");
+
     updateButtons();
 
     // Get the folder where filters should be defined, if that server
@@ -154,16 +176,17 @@ function setFolder(msgFolder)
 {
    if (msgFolder == gCurrentFolder)
      return;
+
    gCurrentFolder = msgFolder;
 
-   //Calling getFilterList will detect any errors in rules.dat, backup the file, and alert the user
+   // Calling getFilterList will detect any errors in rules.dat,
+   // backup the file, and alert the user.
    gCurrentFilterList = msgFolder.getEditableFilterList(gFilterListMsgWindow);
    rebuildFilterList();
 
    // Select the first item in the list, if there is one.
-   var list = document.getElementById("filterList");
-   if (list.itemCount > 0)
-     list.selectItem(list.getItemAtIndex(0));
+   if (gFilterListbox.itemCount > 0)
+     gFilterListbox.selectItem(gFilterListbox.getItemAtIndex(0));
 
    // This will get the deferred to account root folder, if server is deferred.
    // We intentionally do this after setting gCurrentFolder, as we want
@@ -179,40 +202,36 @@ function setFolder(msgFolder)
    runMenu._parentFolder = msgFolder;
    runMenu._ensureInitialized();
 
-   // run filters after the fact not supported by news
-   if (CanRunFiltersAfterTheFact(msgFolder.server)) {
-     document.getElementById("runFiltersFolder").removeAttribute("hidden");
-     document.getElementById("runFiltersButton").removeAttribute("hidden");
-     document.getElementById("folderPickerPrefix").removeAttribute("hidden");
+   let canFilterAfterTheFact = CanRunFiltersAfterTheFact(msgFolder.server);
+   gRunFiltersFolder.hidden = !canFilterAfterTheFact;
+   gRunFiltersButton.hidden = !canFilterAfterTheFact;
+   document.getElementById("folderPickerPrefix").hidden = !canFilterAfterTheFact;
 
-     // for POP3 and IMAP, select the first folder, which is the INBOX
-     document.getElementById("runFiltersFolder").selectedIndex = 0;
+   if (canFilterAfterTheFact) {
+     // Get the first folder for this server. INBOX for
+     // IMAP and POP3 accounts and 1st news group for news.
+     gRunFiltersFolder.selectedIndex = 0;
      runMenu.selectFolder(getFirstFolder(msgFolder));
    }
-   else {
-     document.getElementById("runFiltersFolder").setAttribute("hidden", "true");
-     document.getElementById("runFiltersButton").setAttribute("hidden", "true");
-     document.getElementById("folderPickerPrefix").setAttribute("hidden", "true");
-   }
-
-   // Get the first folder for this server. INBOX for
-   // imap and pop accts and 1st news group for news.
-   updateButtons();
 }
 
-function toggleFilter(aFilter, aIndex)
+/**
+ * Toggle enabled state of a filter, in both the filter properties and the UI.
+ *
+ * @param aFilterItem  an item (row) of the filter list to be toggled
+ */
+function toggleFilter(aFilterItem)
 {
-    if (aFilter.unparseable)
-    {
-      var bundle = document.getElementById("bundle_filter");
-      Services.prompt.alert(window, null, bundle.getString("cannotEnableFilter"));
-      return;
-    }
-    aFilter.enabled = !aFilter.enabled;
+  let filter = aFilterItem._filter;
+  if (filter.unparseable && !filter.enabled)
+  {
+    Services.prompt.alert(window, null, gFilterBundle.getString("cannotEnableFilter"));
+    return;
+  }
+  filter.enabled = !filter.enabled;
 
-    // Now update the appropriate row
-    let row = document.getElementById("filterList").getItemAtIndex(aIndex);
-    row.childNodes[1].setAttribute("enabled", aFilter.enabled);
+  // Now update the checkbox
+  aFilterItem.childNodes[1].setAttribute("enabled", filter.enabled);
 }
 
 // sets up the menulist and the filter list
@@ -231,12 +250,15 @@ function selectFolder(aFolder)
  */
 function currentFilter()
 {
-    let currentItem = document.getElementById("filterList").selectedItem;
-    return currentItem ? currentItem._filter : null;
+  let currentItem = gFilterListbox.selectedItem;
+  return currentItem ? currentItem._filter : null;
 }
 
 function onEditFilter()
 {
+  if (gEditButton.disabled)
+    return;
+
   let selectedFilter = currentFilter();
   if (!selectedFilter)
     return;
@@ -254,7 +276,6 @@ function onEditFilter()
 
 function onNewFilter(emailAddress)
 {
-  let list = document.getElementById("filterList");
   let selectedFilter = currentFilter();
   // If no filter is selected use the first position.
   let position = 0;
@@ -280,7 +301,7 @@ function onNewFilter(emailAddress)
     rebuildFilterList();
 
     // Select the new filter, it is at the position of previous selection.
-    list.selectItem(list.getItemAtIndex(position));
+    gFilterListbox.selectItem(gFilterListbox.getItemAtIndex(position));
   }
 }
 
@@ -290,19 +311,20 @@ function onNewFilter(emailAddress)
  */
 function onDeleteFilter()
 {
-  let list = document.getElementById("filterList");
-  let items = list.selectedItems;
+  if (gDeleteButton.disabled)
+    return;
+
+  let items = gFilterListbox.selectedItems;
   if (!items.length)
     return;
 
   let checkValue = {value:false};
-  let bundle = document.getElementById("bundle_filter");
   if ((Services.prefs.getBoolPref("mailnews.filters.confirm_delete")) &&
       (Services.prompt.confirmEx(window, null,
-                                 bundle.getString("deleteFilterConfirmation"),
+                                 gFilterBundle.getString("deleteFilterConfirmation"),
                                  Services.prompt.STD_YES_NO_BUTTONS,
                                  '', '', '',
-                                 bundle.getString('dontWarnAboutDeleteCheckbox'),
+                                 gFilterBundle.getString('dontWarnAboutDeleteCheckbox'),
                                  checkValue)))
     return;
 
@@ -310,21 +332,21 @@ function onDeleteFilter()
      Services.prefs.setBoolPref("mailnews.filters.confirm_delete", false);
 
   // Save filter position before the first selected one.
-  let newSelectionIndex = list.selectedIndex - 1;
+  let newSelectionIndex = gFilterListbox.selectedIndex - 1;
 
   // Must reverse the loop, as the items list shrinks when we delete.
   for (let index = items.length - 1; index >= 0; --index) {
     let item = items[index];
     gCurrentFilterList.removeFilter(item._filter);
-    document.getElementById("filterList").removeChild(item);
+    gFilterListbox.removeItemAt(gFilterListbox.getIndexOfItem(item));
   }
   updateCountBox();
 
   // Select filter above previously selected if one existed, otherwise the first one.
-  if (newSelectionIndex == -1 && list.itemCount > 0)
+  if (newSelectionIndex == -1 && gFilterListbox.itemCount > 0)
     newSelectionIndex = 0;
   if (newSelectionIndex > -1) {
-    list.selectedIndex = newSelectionIndex;
+    gFilterListbox.selectedIndex = newSelectionIndex;
     updateViewPosition(-1);
   }
 }
@@ -375,28 +397,26 @@ function onBottom(evt) {
  */
 function moveFilter(motion) {
   // At the moment, do not allow moving groups of filters.
-  var list = document.getElementById("filterList");
-  if (list.selectedItems.length != 1)
+  let selectedFilter = currentFilter();
+  if (!selectedFilter)
     return;
-  var activeFilter = list.selectedItems[0]._filter;
+
   var relativeStep = 0;
   var moveFilterNative = null;
 
   switch(motion) {
     case msgMoveMotion.Top:
-      if (activeFilter) {
-        gCurrentFilterList.removeFilter(activeFilter);
-        gCurrentFilterList.insertFilterAt(0, activeFilter);
+      if (selectedFilter) {
+        gCurrentFilterList.removeFilter(selectedFilter);
+        gCurrentFilterList.insertFilterAt(0, selectedFilter);
         rebuildFilterList();
-        document.getElementById("reorderTopButton").disabled = true;
       }
       return;
     case msgMoveMotion.Bottom:
-      if (activeFilter) {
-        gCurrentFilterList.removeFilter(activeFilter);
-        gCurrentFilterList.insertFilterAt(gCurrentFilterList.filterCount, activeFilter);
+      if (selectedFilter) {
+        gCurrentFilterList.removeFilter(selectedFilter);
+        gCurrentFilterList.insertFilterAt(gCurrentFilterList.filterCount, selectedFilter);
         rebuildFilterList();
-        document.getElementById("reorderBottomButton").disabled = true;
       }
       return;
     case msgMoveMotion.Up:
@@ -409,16 +429,16 @@ function moveFilter(motion) {
       break;
   }
 
-  if (!document.getElementById("searchBox").value) {
+  if (!gSearchBox.value) {
     // use legacy move filter code: up, down; only if searchBox is empty
     moveCurrentFilter(moveFilterNative);
     return;
   }
 
-  let nextIndex = list.selectedIndex + relativeStep;
-  let nextFilter = list.getItemAtIndex(nextIndex)._filter;
+  let nextIndex = gFilterListbox.selectedIndex + relativeStep;
+  let nextFilter = gFilterListbox.getItemAtIndex(nextIndex)._filter;
 
-  gCurrentFilterList.removeFilter(activeFilter);
+  gCurrentFilterList.removeFilter(selectedFilter);
 
   // Find the index of the filter we want to insert at.
   let newIndex = -1;
@@ -433,7 +453,7 @@ function moveFilter(motion) {
   if (motion == msgMoveMotion.Down)
     newIndex += relativeStep;
 
-  gCurrentFilterList.insertFilterAt(newIndex, activeFilter);
+  gCurrentFilterList.insertFilterAt(newIndex, selectedFilter);
 
   rebuildFilterList();
 }
@@ -454,13 +474,12 @@ function onFilterUnload()
 
 function onFilterClose()
 {
-  var runButton = document.getElementById("runFiltersButton");
-  if (runButton.getAttribute("label") == runButton.getAttribute("stoplabel")) {
-    var bundle = document.getElementById("bundle_filter");
-    var promptTitle = bundle.getString("promptTitle");
-    var promptMsg = bundle.getString("promptMsg");
-    var stopButtonLabel = bundle.getString("stopButtonLabel");
-    var continueButtonLabel = bundle.getString("continueButtonLabel");
+  if (gRunFiltersButton.getAttribute("label") ==
+      gRunFiltersButton.getAttribute("stoplabel")) {
+    let promptTitle = gFilterBundle.getString("promptTitle");
+    let promptMsg = gFilterBundle.getString("promptMsg");
+    let stopButtonLabel = gFilterBundle.getString("stopButtonLabel");
+    let continueButtonLabel = gFilterBundle.getString("continueButtonLabel");
 
     let result = Services.prompt.confirmEx(window, promptTitle, promptMsg,
                (Services.prompt.BUTTON_TITLE_IS_STRING * Services.prompt.BUTTON_POS_0) +
@@ -479,14 +498,13 @@ function onFilterClose()
 function runSelectedFilters()
 {
   // if run button has "stop" label, do stop.
-  var runButton = document.getElementById("runFiltersButton");
-  if (runButton.getAttribute("label") == runButton.getAttribute("stoplabel")) {
+  if (gRunFiltersButton.getAttribute("label") ==
+      gRunFiltersButton.getAttribute("stoplabel")) {
     gFilterListMsgWindow.StopUrls();
     return;
   }
 
-  var menu = document.getElementById("runFiltersFolder");
-  var folder = menu._folder || menu.selectedItem._folder;
+  var folder = gRunFiltersFolder._folder || gRunFiltersFolder.selectedItem._folder;
 
   let filterList = MailServices.filters.getTempFilterList(folder);
   let folders = Components.classes["@mozilla.org/supports-array;1"]
@@ -497,9 +515,8 @@ function runSelectedFilters()
   filterList.logStream = gCurrentFilterList.logStream;
   filterList.loggingEnabled = gCurrentFilterList.loggingEnabled;
 
-  var list = document.getElementById("filterList");
-  var index = 0;
-  for each (var item in list.selectedItems) {
+  let index = 0;
+  for each (let item in gFilterListbox.selectedItems) {
     filterList.insertFilterAt(index++, item._filter);
   }
 
@@ -528,7 +545,6 @@ function rebuildFilterList()
   // Get filters that match the search box.
   let aTempFilterList = onFindFilter();
 
-  let searchBox = document.getElementById("searchBox");
   let searchBoxFocus = false;
   let activeElement = document.activeElement;
 
@@ -536,7 +552,7 @@ function rebuildFilterList()
   // (probably html:input). Traverse up the parents until the first element
   // with an ID is found. If it is not searchBox, return false.
   while (activeElement != null) {
-    if (activeElement == searchBox) {
+    if (activeElement == gSearchBox) {
       searchBoxFocus = true;
       break;
     }
@@ -547,26 +563,25 @@ function rebuildFilterList()
     activeElement = activeElement.parentNode;
   }
 
-  let list = document.getElementById("filterList");
   // Make a note of which filters were previously selected
   let selectedNames = [];
-  for (let i = 0; i < list.selectedItems.length; i++)
-    selectedNames.push(list.selectedItems[i]._filter.filterName);
+  for (let i = 0; i < gFilterListbox.selectedItems.length; i++)
+    selectedNames.push(gFilterListbox.selectedItems[i]._filter.filterName);
 
   // Save scroll position so we can try to restore it later.
   // Doesn't work when the list is rebuilt after search box condition changed.
-  let firstVisibleRowIndex = list.getIndexOfFirstVisibleRow();
+  let firstVisibleRowIndex = gFilterListbox.getIndexOfFirstVisibleRow();
 
   // listbox.xml seems to cache the value of the first selected item in a
   // range at _selectionStart. The old value though is now obsolete,
   // since we will recreate all of the elements. We need to clear this,
   // and one way to do this is with a call to clearSelection. This might be
   // ugly from an accessibility perspective, since it fires an onSelect event.
-  list.clearSelection();
+  gFilterListbox.clearSelection();
 
   let listitem, nameCell, enabledCell, filter;
   let filterCount = gCurrentFilterList.filterCount;
-  let listitemCount = list.itemCount;
+  let listitemCount = gFilterListbox.itemCount;
   let listitemIndex = 0;
   let tempFilterListLength = aTempFilterList ? aTempFilterList.length - 1 : 0;
   for (let i = 0; i < filterCount; i++) {
@@ -580,7 +595,7 @@ function rebuildFilterList()
     if (listitemCount > listitemIndex) {
       // If there is a free existing listitem, reuse it.
       // Use .children[] instead of .getItemAtIndex() as it is much faster.
-      listitem = list.children[listitemIndex + 1];
+      listitem = gFilterListbox.children[listitemIndex + 1];
       nameCell = listitem.childNodes[0];
       enabledCell = listitem.childNodes[1];
     }
@@ -593,7 +608,7 @@ function rebuildFilterList()
       enabledCell.setAttribute("class", "listcell-iconic");
       listitem.appendChild(nameCell);
       listitem.appendChild(enabledCell);
-      list.appendChild(listitem);
+      gFilterListbox.appendChild(listitem);
       // We have to attach this listener to the listitem, even though we only care
       // about clicks on the enabledCell. However, attaching to that item doesn't
       // result in any events actually getting received.
@@ -606,13 +621,13 @@ function rebuildFilterList()
     listitem._filter = filter;
 
     if (selectedNames.indexOf(filter.filterName) != -1)
-      list.addItemToSelection(listitem);
+      gFilterListbox.addItemToSelection(listitem);
 
     listitemIndex++;
   }
   // Remove any superfluous listitems, if the number of filters shrunk.
   for (let i = listitemCount - 1; i >= listitemIndex; i--) {
-    list.removeChild(list.lastChild);
+    gFilterListbox.removeChild(gFilterListbox.lastChild);
   }
 
   updateViewPosition(firstVisibleRowIndex);
@@ -621,28 +636,28 @@ function rebuildFilterList()
   // If before rebuilding the list the searchbox was focused, focus it again.
   // In any other case, focus the list.
   if (searchBoxFocus)
-    searchBox.focus();
+    gSearchBox.focus();
   else
-    list.focus();
+    gFilterListbox.focus();
 }
 
 function updateViewPosition(firstVisibleRowIndex)
 {
-  let list = document.getElementById("filterList");
   if (firstVisibleRowIndex == -1)
-    firstVisibleRowIndex = list.getIndexOfFirstVisibleRow();
+    firstVisibleRowIndex = gFilterListbox.getIndexOfFirstVisibleRow();
 
   // Restore to the extent possible the scroll position.
-  if (firstVisibleRowIndex && list.itemCount)
-    list.scrollToIndex(Math.min(firstVisibleRowIndex, list.itemCount - 1));
+  if (firstVisibleRowIndex && gFilterListbox.itemCount)
+    gFilterListbox.scrollToIndex(Math.min(firstVisibleRowIndex,
+                                          gFilterListbox.itemCount - 1));
 
-  if (list.selectedCount) {
+  if (gFilterListbox.selectedCount) {
     // Make sure that at least the first selected item is visible.
-    list.ensureElementIsVisible(list.selectedItems[0]);
+    gFilterListbox.ensureElementIsVisible(gFilterListbox.selectedItems[0]);
 
     // The current item should be the first selected item, so that keyboard
     // selection extension can work.
-    list.currentItem = list.selectedItems[0];
+    gFilterListbox.currentItem = gFilterListbox.selectedItems[0];
   }
 
   updateButtons();
@@ -657,40 +672,35 @@ function updateViewPosition(firstVisibleRowIndex)
  */
 function updateButtons()
 {
-    var list = document.getElementById("filterList");
-    var numFiltersSelected = list.selectedItems.length;
+    var numFiltersSelected = gFilterListbox.selectedItems.length;
     var oneFilterSelected = (numFiltersSelected == 1);
 
-    var filter = currentFilter();
-    // "edit" only enabled when one filter selected or if we couldn't parse the filter
-    var disabled = !oneFilterSelected || filter.unparseable
-    document.getElementById("editButton").disabled = disabled;
+    // "edit" is disabled when not exactly one filter is selected
+    // or if we couldn't parse that filter
+    let disabled = !oneFilterSelected || currentFilter().unparseable;
+    gEditButton.disabled = disabled;
 
     // "delete" only disabled when no filters are selected
-    document.getElementById("deleteButton").disabled = !numFiltersSelected;
+    gDeleteButton.disabled = !numFiltersSelected;
 
     // we can run multiple filters on a folder
     // so only disable this UI if no filters are selected
     document.getElementById("folderPickerPrefix").disabled = !numFiltersSelected;
-    document.getElementById("runFiltersFolder").disabled = !numFiltersSelected;
-    document.getElementById("runFiltersButton").disabled = !numFiltersSelected;
-
-    // "up" enabled only if one filter selected, and it's not the first
-    // don't use list.currentIndex here, it's buggy when we've just changed the
+    gRunFiltersFolder.disabled = !numFiltersSelected;
+    gRunFiltersButton.disabled = !numFiltersSelected;
+    // "up" and "top" enabled only if one filter is selected, and it's not the first
+    // don't use gFilterListbox.currentIndex here, it's buggy when we've just changed the
     // children in the list (via rebuildFilterList)
-    var upDisabled = !(oneFilterSelected &&
-                       list.getSelectedItem(0) != list.getItemAtIndex(0));
-    document.getElementById("reorderUpButton").disabled = upDisabled
-    // "down" enabled only if one filter selected, and it's not the last
-    var downDisabled = !(oneFilterSelected && list.selectedIndex < list.itemCount - 1);
-    document.getElementById("reorderDownButton").disabled = downDisabled;
+    disabled = !(oneFilterSelected &&
+                 gFilterListbox.getSelectedItem(0) != gFilterListbox.getItemAtIndex(0));
+    gUpButton.disabled = disabled;
+    gTopButton.disabled = disabled;
 
-    // special buttons
-    var buttonTop = document.getElementById("reorderTopButton");
-    var buttonBottom = document.getElementById("reorderBottomButton");
-
-    buttonTop.disabled = upDisabled;
-    buttonBottom.disabled = downDisabled;
+    // "down" and "bottom" enabled only if one filter is selected,
+    // and it's not the last one
+    disabled = !(oneFilterSelected && gFilterListbox.selectedIndex < gFilterListbox.itemCount - 1);
+    gDownButton.disabled = disabled;
+    gBottomButton.disabled = disabled;
 }
 
 /**
@@ -761,11 +771,10 @@ function onFilterClick(event)
 
     // Remember, we had to attach the click-listener to the whole listitem, so
     // now we need to see if the clicked the enable-column
-    var toggle = event.target.childNodes[1];
+    let toggle = event.target.childNodes[1];
     if ((event.clientX < toggle.boxObject.x + toggle.boxObject.width) &&
         (event.clientX > toggle.boxObject.x)) {
-      var list = document.getElementById("filterList");
-      toggleFilter(event.target._filter, list.getIndexOfItem(event.target));
+      toggleFilter(event.target);
       event.stopPropagation();
     }
 }
@@ -779,32 +788,42 @@ function onFilterDoubleClick(event)
     onEditFilter();
 }
 
-function onFilterListKeyPress(event)
+function onFilterListKeyPress(aEvent)
 {
-  if (event.charCode == KeyEvent.DOM_VK_SPACE)
-  {
-    let list = document.getElementById("filterList");
-    for each (var item in list.selectedItems)
-      toggleFilter(item._filter, list.getIndexOfItem(item));
+  if (aEvent.keyCode) {
+    switch (aEvent.keyCode) {
+      case KeyEvent.DOM_VK_INSERT:
+        if (!document.getElementById("newButton").disabled)
+          onNewFilter();
+        break;
+      case KeyEvent.DOM_VK_DELETE:
+        if (!document.getElementById("deleteButton").disabled)
+          onDeleteFilter();
+        break;
+      case KeyEvent.DOM_VK_ENTER:
+      case KeyEvent.DOM_VK_RETURN:
+        if (!document.getElementById("editButton").disabled)
+          onEditFilter();
+        break;
+    }
   }
-  else switch (event.keyCode)
-  {
-    case KeyEvent.DOM_VK_DELETE:
-      if (!document.getElementById("deleteButton").disabled)
-        onDeleteFilter();
-      break;
-    case KeyEvent.DOM_VK_ENTER:
-    case KeyEvent.DOM_VK_RETURN:
-      if (!document.getElementById("editButton").disabled)
-        onEditFilter();
-      break;
+  else if (!aEvent.ctrlKey && !aEvent.altKey && !aEvent.metaKey) {
+    switch (aEvent.charCode) {
+      case KeyEvent.DOM_VK_SPACE:
+        for each (let item in gFilterListbox.selectedItems) {
+          toggleFilter(item);
+        }
+        break;
+      default:
+        gSearchBox.focus();
+        gSearchBox.value = String.fromCharCode(aEvent.charCode);
+    }
   }
 }
 
 function onTargetSelect(event) {
-  var menu = document.getElementById("runFiltersFolder");
-  menu._folder = event.target._folder;
-  menu.setAttribute("label", event.target._folder.prettyName);
+  gRunFiltersFolder._folder = event.target._folder;
+  gRunFiltersFolder.setAttribute("label", event.target._folder.prettyName);
 }
 
 /**
@@ -861,8 +880,7 @@ function filterSearchMatch(aFilter, aKeyword)
  */
 function onFindFilter()
 {
-  let searchBox = document.getElementById("searchBox");
-  let keyWord = searchBox.value.toLocaleLowerCase();
+  let keyWord = gSearchBox.value.toLocaleLowerCase();
 
   // If searchbox is empty, just return and let rebuildFilterList
   // create an unfiltered list.
@@ -891,10 +909,9 @@ function onFindFilter()
  */
 function resetSearchBox(aFilter)
 {
-  let searchBox = document.getElementById("searchBox");
-  let keyword = searchBox.value.toLocaleLowerCase();
+  let keyword = gSearchBox.value.toLocaleLowerCase();
   if (keyword && (!aFilter || !filterSearchMatch(aFilter, keyword)))
-    searchBox.reset();
+    gSearchBox.reset();
 }
 
 /**
@@ -904,14 +921,20 @@ function updateCountBox()
 {
   let countBox = document.getElementById("countBox");
   let sum = gCurrentFilterList.filterCount;
-  let filterList = document.getElementById("filterList");
-  let len = filterList.itemCount;
+  let len = gFilterListbox.itemCount;
 
-  let bundle = document.getElementById("bundle_filter");
-
-  if (len == sum) // "N items"
-    countBox.value = PluralForm.get(len, bundle.getString("filterCountItems"))
-                               .replace("#1",[len]);
-  else // "N of M"
-    countBox.value = bundle.getFormattedString("filterCountVisibleOfTotal", [len, sum]);
+  if (len == sum) {
+    // "N items"
+    countBox.value = PluralForm.get(len, gFilterBundle.getString("filterCountItems"))
+                               .replace("#1", len);
+    countBox.removeAttribute("filterActive");
+  } else {
+    // "N of M"
+    countBox.value = gFilterBundle.getFormattedString("filterCountVisibleOfTotal",
+                                                      [len, sum]);
+    if (len == 0 && sum > 0)
+      countBox.setAttribute("filterActive", "nomatches");
+    else
+      countBox.setAttribute("filterActive", "matches");
+  }
 }
