@@ -1,39 +1,6 @@
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is mail folder tree code.
- *
- * The Initial Developer of the Original Code is
- *   Joey Minta <jminta@gmail.com>
- * Portions created by the Initial Developer are Copyright (C) 2008
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   Siddharth Agarwal <sid.bugzilla@gmail.com>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or
- * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 Components.utils.import("resource:///modules/folderUtils.jsm");
 Components.utils.import("resource:///modules/iteratorUtils.jsm");
@@ -196,7 +163,8 @@ let gFolderTreeView = {
           this._persistOpenMap = JSON.parse(data);
         } catch (x) {
           Components.utils.reportError(
-            "Failed to read file: " + aJSONFile + " reason: " + x);
+            document.getElementById("bundle_messenger")
+                    .getFormattedString("failedToReadFile", [aJSONFile, x]));
         }
       }
     }
@@ -231,11 +199,14 @@ let gFolderTreeView = {
       let file = Cc["@mozilla.org/file/directory_service;1"]
                     .getService(Ci.nsIProperties).get("ProfD", Ci.nsIFile);
       file.append(aJSONFile);
-      let foStream = Cc["@mozilla.org/network/file-output-stream;1"]
+      let foStream = Cc["@mozilla.org/network/safe-file-output-stream;1"]
                         .createInstance(Ci.nsIFileOutputStream);
 
-      foStream.init(file, 0x02 | 0x08 | 0x20, 0666, 0);
+      foStream.init(file, 0x02 | 0x08 | 0x20, parseInt("0666", 8), 0);
+      // safe-file-output-stream appears to throw an error if it doesn't write everything at once
+      // so we won't worry about looping to deal with partial writes
       foStream.write(data, data.length);
+      foStream.QueryInterface(Ci.nsISafeOutputStream).finish();
       foStream.close();
     }
   },
@@ -604,10 +575,9 @@ let gFolderTreeView = {
       }
       return true;
     }
-    // allow subscribing to feeds by dragging an url to a feed account
-    else if (Array.indexOf(types, "text/x-moz-url") != -1 &&
-             targetFolder.server.type == "rss")
-      return true;
+    // Allow subscribing to feeds by dragging an url to a feed account.
+    else if (targetFolder.server.type == "rss" && dt.mozItemCount == 1)
+      return FeedUtils.getFeedUriFromDataTransfer(dt) ? true : false;
     else if (Array.indexOf(types, "application/x-moz-file") != -1) {
       if (aOrientation != Ci.nsITreeView.DROP_ON)
         return false;
@@ -707,19 +677,16 @@ let gFolderTreeView = {
         }
       }
     }
-    else if (Array.indexOf(types, "text/x-moz-url") != -1) {
-      // This is a potential rss feed to subscribe to
-      // and there's only one, so just get the 0th element.
-      let url = dt.mozGetDataAt("text/x-moz-url", 0);
-      let uri = Cc["@mozilla.org/network/io-service;1"]
-                   .getService(Ci.nsIIOService).newURI(url, null, null);
-      if (!(uri.schemeIs("http") || uri.schemeIs("https")) ||
-             targetFolder.server.type != "rss")
-        return;
 
-      Cc["@mozilla.org/newsblog-feed-downloader;1"]
-         .getService(Ci.nsINewsBlogFeedDownloader)
-         .subscribeToFeed(url, targetFolder, msgWindow);
+    if (targetFolder.server.type == "rss" && count == 1) {
+      // This is a potential rss feed.  A link image as well as link text url
+      // should be handled; try to extract a url from non moz apps as well.
+      let validUri = FeedUtils.getFeedUriFromDataTransfer(dt);
+
+      if (validUri)
+        Cc["@mozilla.org/newsblog-feed-downloader;1"]
+           .getService(Ci.nsINewsBlogFeedDownloader)
+           .subscribeToFeed(validUri.spec, targetFolder, msgWindow);
     }
   },
 
@@ -760,6 +727,7 @@ let gFolderTreeView = {
   getCellText: function ftv_getCellText(aRow, aCol) {
     if (aCol.id == "folderNameCol")
       return this._rowMap[aRow].text;
+    return "";
   },
 
   /**
@@ -843,6 +811,25 @@ let gFolderTreeView = {
     this._toggleRow(aIndex, true);
   },
 
+  recursivelyAddToMap: function ftv_recursivelyAddToMap(aChild, aNewIndex) {
+    // When we add sub-children, we're going to need to increase our index
+    // for the next add item at our own level.
+    let count = 0;
+    if (aChild.children.length && aChild.open) {
+      for (let [i, child] in Iterator(this._rowMap[aNewIndex].children)) {
+        count++;
+        let index = Number(aNewIndex) + Number(i) + 1;
+        this._rowMap.splice(index, 0, child);
+
+        let kidsAdded = this.recursivelyAddToMap(child, index);
+        count += kidsAdded;
+        // Somehow the aNewIndex turns into a string without this.
+        aNewIndex = Number(aNewIndex) + kidsAdded;
+      }
+    }
+    return count;
+  },
+
   _toggleRow: function toggleRow(aIndex, aExpandServer)
   {
     // Ok, this is a bit tricky.
@@ -879,26 +866,7 @@ let gFolderTreeView = {
       // Note that these children may have been open when we were last closed,
       // and if they are, we also have to add those grandchildren to the map
       let oldCount = this._rowMap.length;
-      function recursivelyAddToMap(aChild, aNewIndex, tree) {
-        // When we add sub-children, we're going to need to increase our index
-        // for the next add item at our own level
-        let count = 0;
-        if (aChild.children.length && aChild.open) {
-          for (let [i, child] in Iterator(tree._rowMap[aNewIndex].children)) {
-            count++;
-            var index = Number(aNewIndex) + Number(i) + 1;
-            tree._rowMap.splice(index, 0, child);
-
-            let kidsAdded = recursivelyAddToMap(child, index, tree);
-            count += kidsAdded;
-            // Somehow the aNewIndex turns into a string without this
-            aNewIndex = Number(aNewIndex) + kidsAdded;
-          }
-        }
-        return count;
-      }
-      // work around bug 658534 by passing in "this" instead of let tree = this;
-      recursivelyAddToMap(this._rowMap[aIndex], aIndex, this);
+      this.recursivelyAddToMap(this._rowMap[aIndex], aIndex);
 
       // Add this folder to the persist map
       if (!this._persistOpenMap[this.mode])
@@ -1023,7 +991,7 @@ let gFolderTreeView = {
         searchFolderURIs +=  searchFolder.URI;
       }
       if (!searchFolderURIs.length)
-        return;
+        return null;
       smartFolder = gFolderTreeView._createVFFolder(folderName, smartRootFolder,
                                                     searchFolderURIs, flag);
     }
@@ -1071,7 +1039,10 @@ let gFolderTreeView = {
   {
     let newFolder;
     try {
-      newFolder = parentFolder.addSubfolder(newName);
+      if (parentFolder instanceof(Components.interfaces.nsIMsgLocalMailFolder))
+        newFolder = parentFolder.createLocalSubfolder(newName);
+      else
+        newFolder = parentFolder.addSubfolder(newName);
       newFolder.setFlag(nsMsgFolderFlags.Virtual);
       // provide a way to make the top level folder just a container, not
       // a search folder
@@ -1215,46 +1186,17 @@ let gFolderTreeView = {
     }
   },
 
-  _sortedAccounts: function ftv_getSortedAccounts()
-  {
-      const Cc = Components.classes;
-      const Ci = Components.interfaces;
-      let acctMgr = Cc["@mozilla.org/messenger/account-manager;1"]
-                       .getService(Ci.nsIMsgAccountManager);
-      let accounts = [a for each
-                      (a in fixIterator(acctMgr.accounts, Ci.nsIMsgAccount))];
-      // Bug 41133 workaround
-      accounts = accounts.filter(function fix(a) { return a.incomingServer; });
+  _sortedAccounts: function ftv_getSortedAccounts() {
+    let accounts = allAccountsSorted(true);
 
-      // Don't show deferred pop accounts
-      accounts = accounts.filter(function isNotDeferred(a) {
-        let server = a.incomingServer;
-        return !(server instanceof Ci.nsIPop3IncomingServer &&
-                 server.deferredToAccount);
-      });
+    // Don't show deferred pop accounts.
+    accounts = accounts.filter(function isNotDeferred(a) {
+      let server = a.incomingServer;
+      return !(server instanceof Components.interfaces.nsIPop3IncomingServer &&
+               server.deferredToAccount);
+    });
 
-      function sortAccounts(a, b) {
-        if (a.key == acctMgr.defaultAccount.key)
-          return -1;
-        if (b.key == acctMgr.defaultAccount.key)
-          return 1;
-        let aIsNews = a.incomingServer.type == "nntp";
-        let bIsNews = b.incomingServer.type == "nntp";
-        if (aIsNews && !bIsNews)
-          return 1;
-        if (bIsNews && !aIsNews)
-          return -1;
-
-        let aIsLocal = a.incomingServer.type == "none";
-        let bIsLocal = b.incomingServer.type == "none";
-        if (aIsLocal && !bIsLocal)
-          return 1;
-        if (bIsLocal && !aIsLocal)
-          return -1;
-        return 0;
-      }
-      accounts.sort(sortAccounts);
-      return accounts;
+    return accounts;
   },
 
   /**
@@ -1705,13 +1647,15 @@ let gFolderTreeView = {
 
     let acctMgr = Cc["@mozilla.org/messenger/account-manager;1"]
                      .getService(Ci.nsIMsgAccountManager);
-    for each (let acct in fixIterator(acctMgr.accounts, Ci.nsIMsgAccount)) {
+    for each (let server in fixIterator(acctMgr.allServers, Ci.nsIMsgIncomingServer)) {
       // Skip deferred accounts
-      if (acct.incomingServer instanceof Ci.nsIPop3IncomingServer &&
-          acct.incomingServer.deferredToAccount)
+      if (server instanceof Ci.nsIPop3IncomingServer &&
+          server.deferredToAccount)
         continue;
-      folders.push(acct.incomingServer.rootFolder);
-      this.addSubFolders(acct.incomingServer.rootFolder, folders);
+
+      let rootFolder = server.rootFolder;
+      folders.push(rootFolder);
+      this.addSubFolders(rootFolder, folders);
     }
     return folders;
   },
@@ -2301,9 +2245,6 @@ let gFolderTreeController = {
     for (let i = 0; i < folders.length; i++) {
       folders[i].compactAll(null, msgWindow, folders[i].server.type == "imap" ||
                                              folders[i].server.type == "nntp");
-      // Reset thread pane for non-imap folders.
-      if (gDBView && folders[i].server.type != "imap")
-        this._resetThreadPane();
     }
   },
 
@@ -2316,6 +2257,9 @@ let gFolderTreeController = {
    */
   newVirtualFolder: function ftc_newVFolder(aName, aSearchTerms, aParent) {
     let folder = aParent || gFolderTreeView.getSelectedFolders()[0];
+    if (!folder)
+      folder = GetDefaultAccountRootFolder();
+
     let name = folder.prettyName;
     if (aName)
       name += "-" + aName;
