@@ -3,6 +3,7 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
+Components.utils.import("resource:///modules/hostnameUtils.jsm");
 Components.utils.import("resource://gre/modules/Services.jsm");
 Components.utils.import("resource:///modules/mailServices.js");
 
@@ -38,25 +39,6 @@ function BrowseForLocalFolders()
   currentFolderTextBox.value = selectedFolder.path;
 }
 
-function hostnameIsIllegal(hostname)
-{
-  // XXX TODO do a complete check.
-  // this only checks for illegal characters in the hostname
-  // but hostnames like "...." and "_" and ".111" will get by
-  // my test.  
-  var validChars = hostname.match(/[A-Za-z0-9.-]/g);
-  if (!validChars || (validChars.length != hostname.length)) {
-    return true;
-  }
-
-  return false;
-}
-
-function trim(string)
-{
-  return string.trim();
-}
-
 /**
  * Return server/folder name formatted with server name if needed.
  *
@@ -148,3 +130,15 @@ function openPrefsFromAccountManager(aTBPaneId, aTBTabId, aTBOtherArgs, aSMPaneI
   if (typeof win.goPreferences == "function")
     win.goPreferences(aSMPaneId);
 }
+
+/**
+ * Clean up the hostname or IP.
+ *
+ * @param aHostName  The hostname or IP string to clean up.
+ */
+function cleanUpHostname(aHostName)
+{
+  // TODO: Bug 235312: if UTF8 string was input, convert to punycode using convertUTF8toACE()
+  // but bug 563172 needs resolving first.
+  return aHostName.trim();
+}
