@@ -43,8 +43,10 @@
 #include "nsMsgFolderFlags.h"
 #include "nsMsgUtils.h"
 #include "nsMsgMessageFlags.h"
+#include "nsIMsgSearchTerm.h"
 #include "nsAppDirectoryServiceDefs.h"
 #include "mozilla/Services.h"
+#include "nsIMsgFilter.h"
 
 #define PORT_NOT_SET -1
 
@@ -1586,9 +1588,10 @@ NS_IMETHODIMP
 nsMsgIncomingServer::GetOfflineSupportLevel(int32_t *aSupportLevel)
 {
   NS_ENSURE_ARG_POINTER(aSupportLevel);
-  nsresult rv;
 
-  rv = GetIntValue("offline_support_level", aSupportLevel);
+  nsresult rv = GetIntValue("offline_support_level", aSupportLevel);
+  NS_ENSURE_SUCCESS(rv, rv);
+
   if (*aSupportLevel == OFFLINE_SUPPORT_LEVEL_UNDEFINED)
     *aSupportLevel = OFFLINE_SUPPORT_LEVEL_NONE;
   return NS_OK;
@@ -2271,3 +2274,11 @@ nsMsgIncomingServer::SetForcePropertyEmpty(const char *aPropertyName, bool aValu
  return SetCharValue(nameEmpty.get(),
    aValue ? NS_LITERAL_CSTRING("true") : NS_LITERAL_CSTRING(""));
 }
+
+NS_IMETHODIMP
+nsMsgIncomingServer::GetSortOrder(int32_t* aSortOrder)
+{
+  NS_ENSURE_ARG_POINTER(aSortOrder);
+  *aSortOrder = 100000000;
+  return NS_OK;
+}
