@@ -529,7 +529,7 @@ nsParseMailMessageState::nsParseMailMessageState()
   // a mail message with the X-Spam-Score header, we'll set the
   // "x-spam-score" property of nsMsgHdr to the value of the header.
   m_customDBHeaderValues = nullptr;
-  nsCString customDBHeaders;
+  nsCString customDBHeaders; // not shown in search UI
   nsCOMPtr<nsIPrefBranch> pPrefBranch(do_GetService(NS_PREFSERVICE_CONTRACTID));
   if (pPrefBranch)
   {
@@ -538,6 +538,20 @@ nsParseMailMessageState::nsParseMailMessageState()
      if (customDBHeaders.Find("content-base") == -1)
       customDBHeaders.Insert(NS_LITERAL_CSTRING("content-base "), 0);
      ParseString(customDBHeaders, ' ', m_customDBHeaders);
+
+     // now add customHeaders
+     nsCString customHeadersString; // shown in search UI
+     nsTArray<nsCString> customHeadersArray;
+     pPrefBranch->GetCharPref("mailnews.customHeaders", getter_Copies(customHeadersString));
+     ToLowerCase(customHeadersString);
+     customHeadersString.StripWhitespace();
+     ParseString(customHeadersString, ':', customHeadersArray);
+     for (uint32_t i = 0; i < customHeadersArray.Length(); i++)
+     {
+       if (!m_customDBHeaders.Contains(customHeadersArray[i]))
+         m_customDBHeaders.AppendElement(customHeadersArray[i]);
+     }
+
      if (m_customDBHeaders.Length())
      {
        m_customDBHeaderValues = new struct message_header [m_customDBHeaders.Length()];
@@ -596,6 +610,7 @@ NS_IMETHODIMP nsParseMailMessageState::Clear()
   m_headers.ResetWritePos();
   m_envelope.ResetWritePos();
   m_receivedTime = 0;
+  m_receivedValue.Truncate();
   for (uint32_t i = 0; i < m_customDBHeaders.Length(); i++)
     m_customDBHeaderValues[i].length = 0;
 
@@ -1112,21 +1127,35 @@ SEARCH_NEWLINE:
       while (header->length > 0 &&
         IS_SPACE (header->value [header->length - 1]))
         ((char *) header->value) [--header->length] = 0;
-      if (header == &receivedBy && m_receivedTime == 0)
+      if (header == &receivedBy)
       {
-        // parse Received: header for date.
-        // We trust the first header as that is closest to recipient,
-        // and less likely to be spoofed.
-        nsAutoCString receivedHdr(header->value, header->length);
-        int32_t lastSemicolon = receivedHdr.RFindChar(';');
-        if (lastSemicolon != -1)
+        if (m_receivedTime == 0)
         {
-          nsAutoCString receivedDate;
-          receivedDate = Substring(receivedHdr, lastSemicolon + 1);
-          receivedDate.Trim(" \t\b\r\n");
-          PRTime resultTime;
-          if (PR_ParseTimeString (receivedDate.get(), false, &resultTime) == PR_SUCCESS)
-            m_receivedTime = resultTime;
+          // parse Received: header for date.
+          // We trust the first header as that is closest to recipient,
+          // and less likely to be spoofed.
+          nsAutoCString receivedHdr(header->value, header->length);
+          int32_t lastSemicolon = receivedHdr.RFindChar(';');
+          if (lastSemicolon != -1)
+          {
+            nsAutoCString receivedDate;
+            receivedDate = Substring(receivedHdr, lastSemicolon + 1);
+            receivedDate.Trim(" \t\b\r\n");
+            PRTime resultTime;
+            if (PR_ParseTimeString (receivedDate.get(), false, &resultTime) == PR_SUCCESS)
+              m_receivedTime = resultTime;
+          }
+        }
+        // Someone might want the received header saved.
+        if (m_customDBHeaders.Length())
+        {
+          uint32_t customHeaderIndex = m_customDBHeaders.IndexOf(NS_LITERAL_CSTRING("received"));
+          if (customHeaderIndex != -1)
+          {
+            if (!m_receivedValue.IsEmpty())
+              m_receivedValue.Append(' ');
+            m_receivedValue.Append(header->value, header->length);
+          }
         }
       }
     }
@@ -1301,7 +1330,7 @@ nsresult nsParseMailMessageState::FinalizeHeaders()
 
   if (mozstatus)
   {
-    if (strlen(mozstatus->value) == 4)
+    if (mozstatus->length == 4)
     {
       int i;
       for (i=0,s=mozstatus->value ; i<4 ; i++,s++)
@@ -1616,6 +1645,9 @@ nsresult nsParseMailMessageState::FinalizeHeaders()
         {
           if (m_customDBHeaderValues[i].length)
             m_newMsgHdr->SetStringProperty(m_customDBHeaders[i].get(), m_customDBHeaderValues[i].value);
+          // The received header is accumulated separately
+          if (m_customDBHeaders[i].EqualsLiteral("received") && !m_receivedValue.IsEmpty())
+            m_newMsgHdr->SetStringProperty("received", m_receivedValue.get());
         }
         if (content_type)
         {
@@ -2427,6 +2459,7 @@ nsresult nsParseNewMailState::MoveIncorporatedMessage(nsIMsgDBHdr *mailHdr,
                                                       nsIMsgFilter *filter,
                                                       nsIMsgWindow *msgWindow)
 {
+  NS_ENSURE_ARG_POINTER(destIFolder);
   nsresult rv = NS_OK;
 
   // check if the destination is a real folder (by checking for null parent)
@@ -2462,8 +2495,7 @@ nsresult nsParseNewMailState::MoveIncorporatedMessage(nsIMsgDBHdr *mailHdr,
     do_QueryInterface(static_cast<nsIMsgParseMailMsgState*>(this));
 
   // Make sure no one else is writing into this folder
-  if (destIFolder &&
-      NS_FAILED(rv = destIFolder->AcquireSemaphore (myISupports)))
+  if (NS_FAILED(rv = destIFolder->AcquireSemaphore (myISupports)))
   {
     destIFolder->ThrowAlertMsg("filterFolderDeniedLocked", msgWindow);
     return rv;
@@ -2474,9 +2506,7 @@ nsresult nsParseNewMailState::MoveIncorporatedMessage(nsIMsgDBHdr *mailHdr,
   if (!inputStream)
   {
     NS_ERROR("couldn't get source msg input stream in move filter");
-    if (destIFolder)
-      destIFolder->ReleaseSemaphore (myISupports);
-
+    destIFolder->ReleaseSemaphore (myISupports);
     return NS_MSG_FOLDER_UNREADABLE;  // ### dmb
   }
 
@@ -2494,12 +2524,17 @@ nsresult nsParseNewMailState::MoveIncorporatedMessage(nsIMsgDBHdr *mailHdr,
   nsCOMPtr<nsIMsgDBHdr> newHdr;
 
   if (destMailDB)
-    destMailDB->CopyHdrFromExistingHdr(nsMsgKey_None, mailHdr, true,
-                                       getter_AddRefs(newHdr));
-  uint32_t messageLength;
-  mailHdr->GetMessageSize(&messageLength);
-  rv = AppendMsgFromStream(inputStream, newHdr, messageLength,
-                           destIFolder);
+    rv = destMailDB->CopyHdrFromExistingHdr(nsMsgKey_None, mailHdr, true,
+                                            getter_AddRefs(newHdr));
+  if (NS_SUCCEEDED(rv) && !newHdr)
+    rv = NS_ERROR_UNEXPECTED;
+  if (NS_SUCCEEDED(rv))
+  {
+    uint32_t messageLength;
+    mailHdr->GetMessageSize(&messageLength);
+    rv = AppendMsgFromStream(inputStream, newHdr, messageLength,
+                             destIFolder);
+  }
 
   if (NS_FAILED(rv))
   {
@@ -2517,43 +2552,39 @@ nsresult nsParseNewMailState::MoveIncorporatedMessage(nsIMsgDBHdr *mailHdr,
   bool movedMsgIsNew = false;
   // if we have made it this far then the message has successfully been written to the new folder
   // now add the header to the destMailDB.
-  if (NS_SUCCEEDED(rv) && destMailDB)
+
+  uint32_t newFlags;
+  newHdr->GetFlags(&newFlags);
+  nsMsgKey msgKey;
+  newHdr->GetMessageKey(&msgKey);
+  if (!(newFlags & nsMsgMessageFlags::Read))
   {
-    uint32_t newFlags;
-    newHdr->GetFlags(&newFlags);
-    nsMsgKey msgKey;
-    newHdr->GetMessageKey(&msgKey);
-    if (! (newFlags & nsMsgMessageFlags::Read))
+    nsCString junkScoreStr;
+    (void) newHdr->GetStringProperty("junkscore", getter_Copies(junkScoreStr));
+    if (atoi(junkScoreStr.get()) == nsIJunkMailPlugin::IS_HAM_SCORE)
     {
-      nsCString junkScoreStr;
-      (void) newHdr->GetStringProperty("junkscore", getter_Copies(junkScoreStr));
-      if (atoi(junkScoreStr.get()) == nsIJunkMailPlugin::IS_HAM_SCORE)
-      {
-        newHdr->OrFlags(nsMsgMessageFlags::New, &newFlags);
-        destMailDB->AddToNewList(msgKey);
-        movedMsgIsNew = true;
-      }
+      newHdr->OrFlags(nsMsgMessageFlags::New, &newFlags);
+      destMailDB->AddToNewList(msgKey);
+      movedMsgIsNew = true;
     }
-    nsCOMPtr<nsIMsgFolderNotificationService> notifier(do_GetService(NS_MSGNOTIFICATIONSERVICE_CONTRACTID));
-    if (notifier)
-      notifier->NotifyMsgAdded(newHdr);
-    // mark the header as not yet reported classified
-    destIFolder->OrProcessingFlags(
-    msgKey, nsMsgProcessingFlags::NotReportedClassified);
-    m_msgToForwardOrReply = newHdr;
   }
+  nsCOMPtr<nsIMsgFolderNotificationService> notifier(do_GetService(NS_MSGNOTIFICATIONSERVICE_CONTRACTID));
+  if (notifier)
+    notifier->NotifyMsgAdded(newHdr);
+  // mark the header as not yet reported classified
+  destIFolder->OrProcessingFlags(
+    msgKey, nsMsgProcessingFlags::NotReportedClassified);
+  m_msgToForwardOrReply = newHdr;
+
   if (movedMsgIsNew)
     destIFolder->SetHasNewMessages(true);
   if (m_filterTargetFolders.IndexOf(destIFolder) == -1)
     m_filterTargetFolders.AppendObject(destIFolder);
 
-  if (destIFolder)
-    destIFolder->ReleaseSemaphore (myISupports);
-
+  destIFolder->ReleaseSemaphore (myISupports);
 
   (void) localFolder->RefreshSizeOnDisk();
-  if (destIFolder)
-    destIFolder->SetFlag(nsMsgFolderFlags::GotNew);
+  destIFolder->SetFlag(nsMsgFolderFlags::GotNew);
 
   nsCOMPtr<nsIMsgPluggableStore> store;
   rv = m_downloadFolder->GetMsgStore(getter_AddRefs(store));
@@ -2561,15 +2592,12 @@ nsresult nsParseNewMailState::MoveIncorporatedMessage(nsIMsgDBHdr *mailHdr,
     store->DiscardNewMessage(m_outputStream, mailHdr);
   if (sourceDB)
     sourceDB->RemoveHeaderMdbRow(mailHdr);
-  if (destMailDB)
-  {
-    // update the folder size so we won't reparse.
-    UpdateDBFolderInfo(destMailDB);
-    if (destIFolder != nullptr)
-      destIFolder->UpdateSummaryTotals(true);
 
-    destMailDB->Commit(nsMsgDBCommitType::kLargeCommit);
-  }
+  // update the folder size so we won't reparse.
+  UpdateDBFolderInfo(destMailDB);
+  destIFolder->UpdateSummaryTotals(true);
+
+  destMailDB->Commit(nsMsgDBCommitType::kLargeCommit);
   return rv;
 }
 
