@@ -21,6 +21,8 @@
 using namespace js;
 using namespace JS;
 
+using mozilla::ArrayLength;
+
 static JSBool
 GetBuildConfiguration(JSContext *cx, unsigned argc, jsval *vp)
 {
@@ -167,8 +169,8 @@ GC(JSContext *cx, unsigned argc, jsval *vp)
     /*
      * If the first argument is 'compartment', we collect any compartments
      * previously scheduled for GC via schedulegc. If the first argument is an
-     * object, we collect the object's compartment (any any other compartments
-     * scheduled for GC). Otherwise, we collect call compartments.
+     * object, we collect the object's compartment (and any other compartments
+     * scheduled for GC). Otherwise, we collect all compartments.
      */
     JSBool compartment = false;
     if (argc == 1) {
@@ -650,7 +652,7 @@ static unsigned finalizeCount = 0;
 static void
 finalize_counter_finalize(JSFreeOp *fop, JSObject *obj)
 {
-    JS_ATOMIC_INCREMENT(&finalizeCount);
+    ++finalizeCount;
 }
 
 static JSClass FinalizeCounterClass = {
@@ -687,6 +689,40 @@ FinalizeCount(JSContext *cx, unsigned argc, jsval *vp)
     return true;
 }
 
+static JSBool
+DumpHeapComplete(JSContext *cx, unsigned argc, jsval *vp)
+{
+    const char *fileName = NULL;
+    JSAutoByteString fileNameBytes;
+    if (argc > 0) {
+        Value v = JS_ARGV(cx, vp)[0];
+        if (v.isString()) {
+            JSString *str = v.toString();
+            if (!fileNameBytes.encode(cx, str))
+                return false;
+            fileName = fileNameBytes.ptr();
+        }
+    }
+
+    FILE *dumpFile;
+    if (!fileName) {
+        dumpFile = stdout;
+    } else {
+        dumpFile = fopen(fileName, "w");
+        if (!dumpFile) {
+            JS_ReportError(cx, "can't open %s", fileName);
+            return false;
+        }
+    }
+
+    js::DumpHeapComplete(JS_GetRuntime(cx), dumpFile);
+
+    fclose(dumpFile);
+
+    JS_SET_RVAL(cx, vp, JSVAL_VOID);
+    return true;
+}
+
 JSBool
 MJitChunkLimit(JSContext *cx, unsigned argc, jsval *vp)
 {
@@ -860,6 +896,10 @@ static JSFunctionSpecWithHelp TestingFunctions[] = {
 "isProxy(obj)",
 "  If true, obj is a proxy of some sort"),
 
+    JS_FN_HELP("dumpHeapComplete", DumpHeapComplete, 1, 0,
+"dumpHeapComplete([filename])",
+"  Dump reachable and unreachable objects to a file."),
+
     JS_FN_HELP("mjitChunkLimit", MJitChunkLimit, 1, 0,
 "mjitChunkLimit(N)",
 "  Specify limit on compiled chunk size during mjit compilation."),
